Quadratic formula - Encyclopedia

# Quadratic Formula

In algebra, the quadratic formula gives the solutions of the general quadratic equation. Given a second-degree polynomial of the form a x 2+b x+c=0 ax^{2}+bx+c=0, the values of x satisfying this equation are given by the quadratic formula.

The formula is expressed as:

  x=-b±b 2-4 a c 2 a x={\frac {-b\pm {\sqrt {b^{2}-4ac}}}{2a}}

The quantity under the square root, b 2-4 a c b^{2}-4ac, is known as the discriminant. Its value determines the nature of the solutions.